==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Organitza</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Porta al davant</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Porta endavant</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Envia cap enrere</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Envia al darrere</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Selecciona això</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Configuració general</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Configuració de la imatge</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Color del text</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Amplada</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Número de llavor</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Factor d&apos;ofuscació</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Ombra d&apos;element</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Configuració d&apos;element</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Tanca altres</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tanca-ho tot</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Tanca tot a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Tanca tot a la dreta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Selecció d&apos;eina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Activat</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>↔:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>↕:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilitat de la vora i emplenament</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Vora i emplenament</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Vora i sense emplenament</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Sense vora ni emplenament</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Mida del tipus de lletra</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Negreta</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Subratllat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efectes d&apos;imatge</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Sense efectes</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Ombra</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Escala de grisos</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Vora</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Inverteix els colors</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Restringit</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Quan és actiu, força que el llenç
inclogui la imatge de fons.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>↔:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>↕:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Color de fons del llenç</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Gira la imatge</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° en sentit horari</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° en sentit antihorari</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrari</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Els valors positius giren en sentit horari, els negatius en sentit antihorari.
Els girs que no són múltiples de 90° poden presentar pèrdues de qualitat.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horitzontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Gira</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Inverteix</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Ajusta la mida de la imatge</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantén la relació d&apos;aspecte</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Amplada:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Alçada:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Píxel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Percentatge</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Adhesiu</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Selecciona</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Bolígraf</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcador rectangle</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcador el·lipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Marcador bolígraf</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Fletxa</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Fletxa doble</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Difuminat</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>El·lipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Apuntador numèric</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adhesiu</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixela</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Apuntador de text</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Text amb fletxa</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Número amb fletxa</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Apropa (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Allunya (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Reinicia el zoom (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.6.1.orig.tar.gz: kImageAnnotator-0.6.1/translations/kImageAnnotator_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Organitza</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Porta al davant</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Porta endavant</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Envia cap enrere</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Envia al darrere</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Selecciona això</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Enganxa</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>Controls</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Configuració general</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Configuració de la imatge</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Color del text</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Amplada</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Número de llavor</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Factor d&apos;ofuscació</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Ombra d&apos;element</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Configuració d&apos;element</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Opacitat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Tanca altres</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tanca-ho tot</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Tanca tot a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Tanca tot a la dreta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Selecció d&apos;eina</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Activat</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>Desfés</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refés</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Escapça</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Gira</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>Modifica el llenç</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Tallar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>↔:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>↕:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horitzontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Visibilitat de la vora i emplenament</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Vora i emplenament</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Vora i sense emplenament</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Sense vora ni emplenament</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Mida del tipus de lletra</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Negreta</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Subratllat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efectes d&apos;imatge</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Sense efectes</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Ombra</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Escala de grisos</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Vora</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Inverteix els colors</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Restringit</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Quan és actiu, força que el llenç
inclogui la imatge de fons.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>↔:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>↕:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Color de fons del llenç</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Gira la imatge</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° en sentit horari</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° en sentit antihorari</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Arbitrari</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Els valors positius giren en sentit horari, els negatius en sentit antihorari.
Els girs que no són múltiples de 90° poden presentar pèrdues de qualitat.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horitzontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Gira</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Inverteix</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Ajusta la mida de la imatge</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Mantén la relació d&apos;aspecte</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Amplada:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Alçada:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Píxel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Percentatge</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Adhesiu</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Selecciona</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Bolígraf</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marcador rectangle</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Marcador el·lipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Marcador bolígraf</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Fletxa</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Fletxa doble</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Línia</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Difuminat</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectangle</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>El·lipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Apuntador numèric</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Adhesiu</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixela</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Apuntador de text</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Text amb fletxa</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Número amb fletxa</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Apropa (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Allunya (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Reinicia el zoom (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>Reinicia el zoom</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>Ajusta la imatge</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation>Ajusta la imatge a la vista (%1)</translation>
    </message>
</context>
</TS>
